Ontodocs
=======================

Ontodocs is a Python command line application aimed at facilitating the creation of documentation for ontologies encoded in RDF/OWL.

See [github](https://github.com/lambdamusic/ontodocs)
